@@ -18,7 +18,7 @@ __all__ = ('ZmqSelector', 'ZmqEventLoop', 'ZmqEventLoopPolicy',
            'create_zmq_connection',
            'version_info', 'version')
 
-__version__ = '0.7.1'
+__version__ = '0.9.0'
 
 version = __version__ + ' , Python ' + sys.version
 
@@ -29,7 +29,7 @@ VersionInfo = namedtuple('VersionInfo',
 
 def _parse_version(ver):
     RE = (r'^(?P<major>\d+)\.(?P<minor>\d+)\.'
-          '(?P<micro>\d+)((?P<releaselevel>[a-z]+)(?P<serial>\d+)?)?$')
+          r'(?P<micro>\d+)((?P<releaselevel>[a-z]+)(?P<serial>\d+)?)?$')
     match = re.match(RE, ver)
     try:
         major = int(match.group('major'))
