@@ -7,7 +7,8 @@ import threading
 import weakref
 import zmq
 
-from collections import deque, Iterable, namedtuple
+from collections import deque, namedtuple
+from collections.abc import Iterable
 
 from .interface import ZmqTransport, ZmqProtocol
 from .log import logger
@@ -87,7 +88,7 @@ def create_zmq_connection(protocol_factory, zmq_type, *,
 
     try:
         if zmq_sock is None:
-            zmq_sock = zmq.Context().instance().socket(zmq_type)
+            zmq_sock = zmq.Context.instance().socket(zmq_type)
         elif zmq_sock.getsockopt(zmq.TYPE) != zmq_type:
             raise ValueError('Invalid zmq_sock type')
     except zmq.ZMQError as exc:
@@ -653,7 +654,10 @@ class _ZmqTransportImpl(_BaseTransport):
         if not self._closing:
             self._closing = True
             if not self._paused:
-                self._loop.remove_reader(self._zmq_sock)
+                if self._zmq_sock.closed:
+                    self._loop._remove_reader(self._zmq_sock)
+                else:
+                    self._loop.remove_reader(self._zmq_sock)
         self._conn_lost += 1
         self._loop.call_soon(self._call_connection_lost, exc)
 
