@@ -9,6 +9,11 @@ from .log import logger
 from .packer import _Packer
 from aiozmq import interface
 
+if hasattr(asyncio, 'ensure_future'):
+    ensure_future = asyncio.ensure_future
+else:  # Deprecated since Python version 3.4.4.
+    ensure_future = getattr(asyncio, 'async')
+
 
 class Error(Exception):
     """Base RPC exception"""
@@ -248,7 +253,7 @@ class _BaseServerProtocol(_BaseProtocol):
                     pprint.pformat(args), pprint.pformat(kwargs))  # noqa
 
     def add_pending(self, coro):
-        fut = asyncio.async(coro, loop=self.loop)
+        fut = ensure_future(coro, loop=self.loop)
         self.pending_waiters.add(fut)
         return fut
 
